@@ -53,9 +53,6 @@
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
 #include <libempathy/empathy-debug.h>
 
-/* Flashing delay for icons (milliseconds). */
-#define FLASH_TIMEOUT 500
-
 /* Active users are those which have recently changed state
  * (e.g. online, offline or from normal to a busy state).
  */
@@ -509,10 +506,9 @@ contact_list_view_key_press_event_cb (EmpathyContactListView *view,
 }
 
 static void
-contact_list_view_row_activated_cb (EmpathyContactListView *view,
-				    GtkTreePath            *path,
-				    GtkTreeViewColumn      *col,
-				    gpointer                user_data)
+contact_list_view_row_activated (GtkTreeView       *view,
+				 GtkTreePath       *path,
+				 GtkTreeViewColumn *column)
 {
 	EmpathyContactListViewPriv *priv = GET_PRIV (view);
 	EmpathyContact             *contact;
@@ -523,14 +519,14 @@ contact_list_view_row_activated_cb (EmpathyContactListView *view,
 		return;
 	}
 
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
-
+	model = GTK_TREE_MODEL (priv->store);
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter,
 			    EMPATHY_CONTACT_LIST_STORE_COL_CONTACT, &contact,
 			    -1);
 
 	if (contact) {
+		DEBUG ("Starting a chat");
 		empathy_dispatcher_chat_with_contact (contact);
 		g_object_unref (contact);
 	}
@@ -951,7 +947,7 @@ contact_list_view_set_list_features (EmpathyContactListView         *view,
 				   G_N_ELEMENTS (drag_types_dest),
 				   GDK_ACTION_MOVE | GDK_ACTION_COPY);
 	} else {
-		/* FIXME: URI could still be  droped depending on FT feature */
+		/* FIXME: URI could still be droped depending on FT feature */
 		gtk_drag_dest_unset (GTK_WIDGET (view));
 	}
 
@@ -1029,8 +1025,9 @@ contact_list_view_set_property (GObject      *object,
 static void
 empathy_contact_list_view_class_init (EmpathyContactListViewClass *klass)
 {
-	GObjectClass   *object_class = G_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+	GObjectClass     *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass   *widget_class = GTK_WIDGET_CLASS (klass);
+	GtkTreeViewClass *tree_view_class = GTK_TREE_VIEW_CLASS (klass);
 
 	object_class->finalize = contact_list_view_finalize;
 	object_class->get_property = contact_list_view_get_property;
@@ -1041,12 +1038,13 @@ empathy_contact_list_view_class_init (EmpathyContactListViewClass *klass)
 	widget_class->drag_begin         = contact_list_view_drag_begin;
 	widget_class->drag_data_get      = contact_list_view_drag_data_get;
 	widget_class->drag_end           = contact_list_view_drag_end;
-	/* FIXME: noticed but when you drag the row over the treeview
-	 * fast, it seems to stop redrawing itself, if we don't
-	 * connect this signal, all is fine.
-	 */
 	widget_class->drag_motion        = contact_list_view_drag_motion;
 
+	/* We use the class method to let user of this widget to connect to
+	 * the signal and stop emission of the signal so the default handler
+	 * won't be called. */
+	tree_view_class->row_activated = contact_list_view_row_activated;
+
 	signals[DRAG_CONTACT_RECEIVED] =
 		g_signal_new ("drag-contact-received",
 			      G_OBJECT_CLASS_TYPE (klass),
@@ -1105,9 +1103,6 @@ empathy_contact_list_view_init (EmpathyContactListView *view)
 	g_signal_connect (view, "key-press-event",
 			  G_CALLBACK (contact_list_view_key_press_event_cb),
 			  NULL);
-	g_signal_connect (view, "row-activated",
-			  G_CALLBACK (contact_list_view_row_activated_cb),
-			  NULL);
 	g_signal_connect (view, "row-expanded",
 			  G_CALLBACK (contact_list_view_row_expand_or_collapse_cb),
 			  GINT_TO_POINTER (TRUE));
@@ -1192,31 +1187,22 @@ empathy_contact_list_view_get_selected_group (EmpathyContactListView *view)
 
 static gboolean
 contact_list_view_remove_dialog_show (GtkWindow   *parent, 
-				      const gchar *window_title, 
-				      const gchar *text)
+				      const gchar *message, 
+				      const gchar *secondary_text)
 {
-	GtkWidget *dialog, *label, *image, *hbox;
+	GtkWidget *dialog;
 	gboolean res;
 	
-	dialog = gtk_dialog_new_with_buttons (window_title, parent,
-					      GTK_DIALOG_MODAL,
-  					      GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
-					      GTK_STOCK_DELETE, GTK_RESPONSE_YES,
-					      NULL);
-	gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
+	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL,
+					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+					 "%s", message);
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
+				GTK_STOCK_DELETE, GTK_RESPONSE_YES,
+				NULL);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  "%s", secondary_text);
 	 
-	label = gtk_label_new (text);
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
-	 
-	hbox = gtk_hbox_new (FALSE, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), image);
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), label);	 
-	gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox);
-
-	gtk_widget_show (image);
-	gtk_widget_show (label);
-	gtk_widget_show (hbox);
 	gtk_widget_show (dialog);
 	 
 	res = gtk_dialog_run (GTK_DIALOG (dialog));
